=======
Welcome
=======

|build-status|
|docs|
|license|
|pypi-python|
|pypi-version|


`qwikidata` is a Python package with tools that allow you to interact with Wikidata_.

The package defines a set of classes that allow you to represent Wikidata entities
in a Pythonic way.  It also provides a Pythonic way to access three data sources,

* `linked data interface`_
* `sparql query service`_
* `json dump`_


Quick Install
=============

Requirements
------------

* python >= 3.5

Install with pip
----------------

You can install the most recent version using pip,

.. code-block:: bash

  pip install qwikidata


Quick Examples
==============

Please see the,

* `examples folder`_

OR

* `readthedocs`_


License
=======

Licensed under the Apache 2.0 License. Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.


Copyright
=========

Copyright 2019 Kensho Technologies, LLC.


Important Links
===============

`readthedocs`_ | `PyPI`_ | `github`_



.. |build-status| image:: https://img.shields.io/travis/kensho-technologies/qwikidata.svg?style=flat
    :alt: Build Status
    :scale: 100%
    :target: https://travis-ci.org/kensho-technologies/qwikidata

.. |docs| image:: https://readthedocs.org/projects/qwikidata/badge/?version=latest
    :alt: Documentation Status
    :scale: 100%
    :target: https://qwikidata.readthedocs.io/en/latest/?badge=latest

.. |license| image:: https://img.shields.io/badge/License-Apache%202.0-blue.svg
    :alt: License
    :scale: 100%
    :target: https://opensource.org/licenses/Apache-2.0

.. |pypi-python| image:: https://img.shields.io/pypi/pyversions/qwikidata.svg
    :alt: PyPI Python
    :scale: 100%
    :target: https://pypi.python.org/pypi/qwikidata

.. |pypi-version| image:: https://img.shields.io/pypi/v/qwikidata.svg
   :alt: PyPI Version
   :scale: 100%
   :target: https://pypi.python.org/pypi/qwikidata


.. _Wikidata: https://www.wikidata.org/wiki/Wikidata:Main_Page
.. _linked data interface: https://www.wikidata.org/wiki/Wikidata:Data_access
.. _sparql query service: https://www.wikidata.org/wiki/Wikidata:SPARQL_query_service
.. _json dump: https://www.wikidata.org/wiki/Wikidata:Database_download
.. _examples folder: https://github.com/kensho-technologies/qwikidata/tree/master/examples
.. _readthedocs: https://qwikidata.readthedocs.io/en/stable/readme.html
.. _PyPI: https://pypi.org/project/qwikidata/
.. _github: https://github.com/kensho-technologies/qwikidata/
